*To label missing values on 2004 and 2011 datasets

*********************************
*Syntax produced by the 2011 WERS Research Team
*********************************
clear all
set more off

capture log close
log using "$path_log\label_missings.log", replace

**************************************************************
*Notes
**************************************************************
*This file opens each of the 2011 and 2004 datasets (SEQ, MQ and WRQ) in turn and recodes the missing values to Stata format
*Then labels missing values (only required for 2004 data files)
*Then saves version of each dataset with missing values in Stata format (with the suffix _converted) 
**************************************************************

*2011 SEQ
use "$path_2011_raw\wers11_seq_general_use_missings_coded_numeric_July2013.dta", clear

*Recode missing values to Stata format
*Exclude string variables
quietly: ds, not(type string)
quietly: recode `r(varlist)' (-9=.a) (-8=.b) (-6=.c) (-2=.d) (-1=.e)

sort serno
compress
save "$path_derived\wers11_seq_general_use_missings_coded_numeric_July2013_converted.dta", replace

*2011 MQ
use "$path_2011_raw\wers11_mq_general_use_missings_coded_numeric_July2013.dta", clear

*Exclude string variables
quietly: ds, not(type string)
quietly: recode `r(varlist)' (-9=.a) (-8=.b) (-6=.c) (-2=.d) (-1=.e)

sort serno
compress
save "$path_derived\wers11_mq_general_use_missings_coded_numeric_July2013_converted.dta", replace

*2011 WRQ
use "$path_2011_raw\wers11_wrq_general_use_missings_coded_numeric_July2013.dta", clear

*Exclude string variables
quietly: ds, not(type string)
quietly: recode `r(varlist)' (-9=.a) (-8=.b) (-6=.c) (-2=.d) (-1=.e)

sort serno
compress
save "$path_derived\wers11_wrq_general_use_missings_coded_numeric_July2013_converted.dta", replace

*2004 SEQ
use "$path_2004_raw\xs04_seqv2.dta", clear

*Exclude string variables
quietly: ds, not(type string)
quietly: recode `r(varlist)' (-9=.a) (-8=.b) (-6=.c) (-2=.d) (-1=.e)

*Label the missing values
quietly: label dir 
foreach X in `r(names)' {
	lab define `X' .a "Refusal" .b "Don't know" .c "Multi-coded" .d "Schedule not applicable" .e "Item not applicable", add
}

sort serno
compress
save "$path_derived\xs04_seqv2_converted.dta", replace

*2004 MQ
use "$path_2004_raw\xs04_mqv2.dta", clear

*Exclude string variables
quietly: ds, not(type string)
quietly: recode `r(varlist)' (-9=.a) (-8=.b) (-6=.c) (-2=.d) (-1=.e)

*Label the missing values
quietly: label dir 
foreach X in `r(names)' {
	lab define `X' .a "Refusal" .b "Don't know" .c "Multi-coded" .d "Schedule not applicable" .e "Item not applicable", add
}

sort serno
compress
save "$path_derived\xs04_mqv2_converted.dta", replace

*2004 WRQ
use "$path_2004_raw\xs04_erqv2.dta", clear

*Exclude string variables
quietly: ds, not(type string)
quietly: recode `r(varlist)' (-9=.a) (-8=.b) (-6=.c) (-2=.d) (-1=.e)

*Label the missing values
quietly: label dir 
foreach X in `r(names)' {
	lab define `X' .a "Refusal" .b "Don't know" .c "Multi-coded" .d "Schedule not applicable" .e "Item not applicable", add
}

sort serno
compress
save "$path_derived\xs04_erqv2_converted.dta", replace

log close
