*==============================================================================*
*                            Description of dofile                             *
/*=============================================================================*
This master dofile - provided by the WERS team - prepares and merges the different
WERS datafiles from 2011 and 2004, namely the data from the management questionnaire, 
the data from the employee questionnaire, and the data from the employee representative
questionnaire.

The complete WERS 2011 and WERS 2004 files (datasets, do-files, and documentation)
used in this study were downloaded on 27 June 2016.

Parts of the code in the merging.do-, mqsetup.do-, and wrq_setup.do files generated errors.
These errors are indicated below, and were addressed as follows:

-->error variable not found: code was changed to capital letters to match dataset
-->error file not found: code was changed to the correct name of the file*/

*Master
*********************************
*Syntax produced by the 2011 WERS Research Team
*********************************
*This master do file runs all the necessary do files in order to combine the 2004
*and 2011 WERS datasets and create derived variables used in the primary analysis

*********************************
*Set parameters here
*********************************

clear all
set matsize 5000
set memory 760000 
set more off 

*********************************
* Set file paths
*********************************
* Before running this syntax, these file paths first need to be amended (as explained in the accompanying note for users)
* path_2004_raw is the location for the original 2004 dataset (as deposited)
* path_2011_raw is the location for the original 2011 dataset (as deposited)
* path_extradata is the location for the additional data files required to run this syntax 
* path_derived is where all resulting datasets are saved 
* path_log is the location for all log files 
* path_do is the location where all the do files should be saved

global path_2004_raw "SET YOUR PATH"
global path_2011_raw "SET YOUR PATH"
global path_extradata "SET YOUR PATH"
global path_derived "SET YOUR PATH"
global path_log	"SET YOUR PATH"
global path_do "SET YOUR PATH"

*********************************
* Run do files (consecutively) to set up data files and create derived variables
*********************************

*Run syntax to label missing values in 2004 and 2011 datasets
do "$path_do\label_missings.do"

*Run syntax to merge the 2004 and 2011 MQ, WRQ and SEQs into a single file and derive variables to identify observations from each individual dataset
do "$path_do\merging.do"

/* edited by Dragana Stojmenovska 29 June 2016, errors in merging.do:
-vars not found: nsicode, xsoc2000, zallemps;
-file WERS 2004 XS MQ weight with non-response adjustment.dta not found; 
file WERS 2004 XS SEQ weight revised to incorporate new MQ weight with non-response adjustment.dta not found;
file WERS 2011 panel weight for 2004 SEQs.dta not found
*/

*Run syntax to set-up MQ
do "$path_do\mqsetup.do"

/* edited by Dragana Stojmenovska 29 June 2016, errors in mqsetup.do:
-vars not found: btitle, fperwh01-fperwh10, fprpoc01-fprpoc10, foccgr01-foccgr10,
fliving, fperfo, fprod, faction, gprocedu, gissues1-gissues5, xgissue1-xgissue3,
gactio01-gactio09, gpstyr1-gpstyr7, gactyr01-gactyr10, horwarn, hwarning, hsuspend, 
hdeduct, hdismiss, htransf, hraised, coffjobt, ipract1*, ipract11, ipract2*, ipract21, 
ipract3*, ipract31, impract4*, impract41, impract5*, impract51, zmalprt, zfemprt 
eunionum, eunionck, erecog01-erecog10, iflex1-iflex9, ifamily1-ifamily5, egrieva,
fsocin01-fsocin10, ahowch01-ahowch12, htype01-htype17, jobsec01, lmancha1-lmancha9,
aconint, xdconsu1-xdconsu3, ediscipa, egrievb, ediscipb, xhtype1-xhtype3, hsusty01-hsusty13,
xhsusty1-xhsusty3, d1whi02, fwhodid, fconsneg;
-file WERS 2004 MQ edited recognition dvs.dta not found
-unrecognized command:  recode2 (solution is to install module)
-ngor already defined; nssr already defined; skipped code running these two 
-in line 3450 (3447 in downloaded do) there is a "/*" that stars out the rest of the do-file. I have removed 
the star - which appeared to be an error - after correspondence with the WERS team. 
-variable nsic2003 not found; solution is to replace nsic2003 with asic2003 (correspondence with the WERS team)
-variable niflex1 not found, recode niflex to nIFLEX; 
-label w_m_w_m_KPROSER not found; code "label w_m_w_m_KPROSER not found" deleted (line 6830)
*/
*/

*Run  syntax to set-up SEQ
do "$path_do\seq_set-up.do"

*Run syntax to set-up WRQ
do "$path_do\wrq_setup.do"

/*edited by Dragana Stojmenovska 2 July 2016, errors in wrq_setup.do:
-vars not found: wlethnic, wahours, wahrdk, waprot01-waprot13, 
xwaprot1-xwaprot3, waprotim, wcselre1-wcselre3, wchowrep, wbnumrep,
wcnuoth, wcnunum, wcpropfe, wddiscip, wdgriev;
*/

*********************************
* The end result will be to save a data file named 'mq&seq&wrq_derived.dta' in 
* the location specified by the global $path_derived






