*To merge 2004 and 2011 MQ, WRQ and SEQs into a single file

*********************************
*Syntax produced by the 2011 WERS Research Team
*********************************
clear all
set more off

cap log close
log using "$path_log\merging.log", replace

************************************************************
*Notes
************************************************************
*This file merges the 2004 and 2011 MQ, WRQ and SEQs into a single file 
*Defining labels where the variables are derived when merging the data for each year
*This is because otherwise the value labels which are not attached to a variable are lost when renaming the value labels and drop the old labels
*Once the 2004 and 2011 datasets are merged, revert to the convention of defining all value labels together, before deriving the variables

*Open the 2004 MQ
*Rename 2004 MQ value labels which have identical names to those used in the 2004 WRQ and SEQ, but correspond to different variables 
*Attach renamed value labels to 2004 MQ variables 
*Match on revised non-response weight for 2004
*Match the 2004 WRQ onto the 2004 MQ 
*Rename 2004 WRQ value labels which have identical names to those used in the 2004 SEQ, but correspond to different variables 
*Attach renamed value labels to 2004 WRQ variables 
*Match the 2004 SEQ to the 2004 MQ and WRQ 
*Derive a variable to identify respondents for each 2004 case e.g. MQ only, MQ and WRQ only etc (nresp) 
*Match on the 2011 equivalent to the 2004 serno 
*Save a version of the 2004 which contains the 2011 equivalent serial number 

*Open the 2011 MQ and rename 2011 MQ value labels which have identical names to those used in the 2011 WRQ and SEQ, but correspond to different variables 
*Attach renamed value labels to 2011 MQ variables 
*Match the 2011 WRQ onto the 2011 MQ 
**Select a single observation for each rep type in each workplace (selecting most senior rep, rep with greatest number of years of service) HB
*Rename 2011 WRQ value labels which have identical names to those used in the 2011 SEQ, but correspond to different variables 
*Attach renamed value labels to 2011 WRQ variables 
*Match the 2011 SEQ to the 2011 MQ and WRQ 
*Derive a variable to identify respondents for each 2011 case e.g. MQ only, MQ and WRQ only etc (nresp) 
*Save version of 2011 dataset which contains all MQ, WRQ and SEQ responses 

*Open the 2004 dataset and rename 2004 value labels which have identical names to those used in 2011 
*Attach renamed value labels to 2004 variables 
*Rename the 2004 variables which have an exact 2011 equivalent 
*Save a version of the 2004 dataset with the renamed variables 
*Open the 2011 data and append the 2004 data 
*Derive a year dummy (nyear) 
*Define value labels 
*Derive variables to select subsets of observations for individual datasets:
*Derive variable to select single MQ observation per wp per year (nmq) 
*Derive variable to indicate the source of the data e.g. 2004 X-section, 2011 X-section, 2004 panel etc. (nsource) 
*Derive a variable to select a single WRQ observation for each worker rep for each year (nwrq) 
*Derive a variable to select 2004 MQ cases only (nmq2004) 
*Derive a variable to select 2011 MQ cases only (nmq2011) 
*Derive variable to select MQ panel cases only (npanel) 
*Derive variable to identify PQ year (npayyr) 
*Derive variable to select 2004 WRQ cases only (nwrq2004) 
*Derive variable to select 2011 WRQ cases only (nwrq2011) 
*Derive variable to select 2004 SEQ cases only (nseq2004) 
*Derive variable to select 2011 SEQ cases only (nseq2011) 
*Derive variable to select SEQ cases only (nseq) 
*Derive variable to select all SEQ responses for panel wps where employees responded in both 2004 and 2011 (nseqpan) 

*Save version of dataset containing all 2004 and 2011 MQ, WRQ and SEQ cases and derived variables to identify years and cases from each individual dataset 


************************************************************
*Match 2004 WRQ and SEQ to the 2004 MQ
************************************************************
use "$path_derived\xs04_mqv2_converted.dta", clear

quietly: label dir
foreach X in `r(names)' {
	label copy `X' m_`X'
	lab drop `X'
}

*This part attaches the renamed value labels to the variables
quietly: ds, has(vallabel)
foreach a of varlist `r(varlist)'{
	local b : value label `a'
	lab val `a' m_`b'
	}

*Rename SIC03 variable to be consistent with name used in 2011
rename Nsicode nsicod03

*Rename xsoc2000 as there is a variable on the SEQ with the same name
rename XSOC2000 nsoc2000

*Rename all of the existing 2004 weights to identify the dates from which they originate
rename estwtnr estwtnr_jun05 
rename empwtnr empwtnr_jun05

*Match on the revised MQ weight for 2004 which now incorporates a non-response adjustment
merge 1:1 serno using "$path_extradata\WERS_2004_XS_MQ_weight_with_non-response_adjustment.dta", nogen keep(master match)
rename new_estwtnr estwtnr_apr13
replace estwtnr_apr13=estwtnr_apr13/6990
gen empwtnr_apr13=(estwtnr_apr13*ZALLEMPS)/31.88
label var estwtnr_apr13 "MQ establishment weight incorporating non-response adjustment - April 2013"
label var empwtnr_apr13 "MQ employment weight incorporating non-response adjustment - April 2013"

*Generate new variable w5serial (equivalent to serno) later used for matching on additional data
gen w5serial=serno


******** Match on the 2004 WRQ ***********
sort serno
merge 1:m serno using "$path_derived\xs04_erqv2_converted.dta"
ta _m

*Rename the existing weight to identify the date from which it originates
*Also create an apr13 equivalent for the 2004 WRQ which, like the jun05 variant is simply estwtnr renamed
rename wrqwtnr wrqwtnr_jun05
gen wrqwtnr_apr13=estwtnr_apr13 if _m==3
label var wrqwtnr_apr13 "WRQ weight based on MQ establishment weight that incporates non-response adjustment - April 2013"

*Label responses as either MQ and WRQ, or MQ only
gen t=0 if _m==1
replace t=1 if _m==3
lab define t 0 "MQ only" 1 "MQ and WRQ"
drop _m

quietly: label dir
foreach X in `r(names)' {
	label copy `X' w_`X'
	lab drop `X'
}

*This part attaches the renamed value labels to the variables
quietly: ds, has(vallabel)
foreach a of varlist `r(varlist)'{
	local b : value label `a'
	lab val `a' w_`b'
	}


******** Match on the 2004 SEQ ***********

sort serno
merge m:m serno using "$path_derived\xs04_seqv2_converted.dta"
ta _m

*Rename the original SEQ weight from June 2005, then match on the new 2004 SEQ weight from April 2013
rename seqwtnr2 seqwtnr2_jun05
merge m:1 serno persid using "$path_extradata\WERS_2004_XS_SEQ_weight_revised_to_incorporate_new_MQ_weight_with_non-response_adjustment.dta", nogen keep(master match) keepusing(new_seqwtnr2)
rename new_seqwtnr2 seqwtnr2_apr13
label var seqwtnr2_apr13 "SEQ weight based on MQ weight that incorporates non-response adjusment - April 2013"

*Label responses as MQ, WRQ or SEQ
gen nresp=0 if _m==1 & t==0
replace nresp=1 if _m==1 & t==1
replace nresp=2 if _m==3 & t==0
replace nresp=3 if _m==3 & t==1
lab var nresp "Respondent"
lab define nresp 0 "MQ only" 1 "MQ and WRQ only" 2 "MQ and SEQ only" 3 "MQ, WRQ and SEQ"
lab val nresp nresp
drop _m t

*Add the equivalent 2011 serno

rename serno old_serno
sort w5serial
merge m:m w5serial using "$path_2011_raw\wers_2004_xsection_status_in_2011.dta"
ta _m

*LS - had to alter this slightly in order to run on deposited data
*We could probably delete old_serno and serial
drop _m

*drop old_serno _m
*gen serno=serial
*drop serial

*Save dataset containing the 2004 MQ, WRQ and SEQ
quietly: compress
save "$path_derived\mq&wrq&seq_2004.dta", replace

************************************************************
*Match the 2011 WRQ and SEQ to the MQ
************************************************************
* Open 2011 MQ data file 
use "$path_derived\wers11_mq_general_use_missings_coded_numeric_July2013_converted.dta", clear

quietly: label dir
foreach X in `r(names)' {
	label copy `X' m_`X'
	lab drop `X'
}

*This part attaches the renamed value labels to the variables
quietly: ds, has(vallabel)
foreach a of varlist `r(varlist)'{
	local b : value label `a'
	lab val `a' m_`b'
	}


*LS - No longer needed
* Match on Oct 12 vintage of weights and a couple of other indicators that we will use for joiners/leavers
*sort serno
*merge 1:1 serno using "$path_derived\Weights and additional sample vars 16th Oct 12.dta", keep(master match) nogen
*foreach i of varlist estwtnrc empwtnrc estwtnr empwtnr pqwtnr pqempwtnr {
*	rename `i' `i'_oct12
*}
*su *wt*


******* Match on WRQ *******

* Match on WRQ data 
sort serno
merge 1:m serno using "$path_derived\wers11_wrq_general_use_missings_coded_numeric_July2013_converted.dta"
ta _m

*LS - No longer needed
* I rename the weights to indicate the vintage
*foreach i of varlist tuwtnrc ntuwtnrc wrqwtnrc pairwtnrc tuwtnr ntuwtnr wrqwtnr tuwtnrp {
*	rename `i' `i'_apr13
*}
* I drop tuwtnr and tuwtnrc, and I drop ntuwtnr and ntuwtnrc, because these are wrapped up together in wrqwtnr and wrqwtnrc
*drop tuwtnr_apr13 tuwtnrc_apr13 ntuwtnr_apr13 ntuwtnrc_apr13
*su *wt*

*LS - Think this already been done in deposited data, so starred out here
*Two interviews with the same type of rep in two workplaces - rep of JC dealing with largest range of issues
*Should not have more than one interview with a single rep type within a workplace, so will need to drop multiple cases
*This reduces the number of wrq interviews to 502
*In one case, both respondents say they are the most senior union rep, so in this case I'm selecting on the length of time they have been a rep as well as their seniority
*bysort serno wareptyp: gen t=_n if serno~=. & wareptyp<.
*bysort serno wareptyp: gen t1=_N if serno~=. & wareptyp<.
*ta t
*bysort serno wareptyp (wawrepse -warepyrs): gen t2=_n if t1==2
*li serno wareptyp wawrepse warepyrs t2 if t1==2
*drop if t1==2 & t2>1 & t2<.
*drop t t1 t2

*Label responses as either MQ and WRQ, or MQ only
gen t=0 if _m==1
replace t=1 if _m==3
lab define t 0 "MQ only" 1 "MQ and WRQ"
drop _m

quietly: label dir
foreach X in `r(names)' {
	label copy `X' w_`X'
	lab drop `X'
}

*This part attaches the renamed value labels to the variables
quietly: ds, has(vallabel)
foreach a of varlist `r(varlist)'{
	local b : value label `a'
	lab val `a' w_`b'
	}


******* Match on SEQ *******

*Match in SEQ data

sort serno
merge m:m serno using "$path_derived\wers11_seq_general_use_missings_coded_numeric_July2013_converted.dta"
ta _m


*Label responses as MQ, WRQ or SEQ (nresp)
gen nresp=0 if _m==1 & t==0
replace nresp=1 if _m==1 & t==1
replace nresp=2 if _m==3 & t==0
replace nresp=3 if _m==3 & t==1
lab var nresp "Respondent"
lab define nresp 0 "MQ only" 1 "MQ and WRQ only" 2 "MQ and SEQ only" 3 "MQ, WRQ and SEQ"
lab val nresp nresp
drop _m t

*Save dataset containing the 2011 MQ, WRQ and SEQ
sort serno
quietly: compress
save "$path_derived\mq&wrq&seq_2011.dta", replace

************************************************************
*Append 2004 data to 2011 data
************************************************************
use "$path_derived\mq&wrq&seq_2004.dta", clear

*Some of the value labels have the same name on both datasets, but the labels correspond to different questions, which results in the 2011 data being wrongly labelled
*Rename all the 2004 value labels to have an s_ prefix to avoid the 2011 data becoming wrongly labelled
quietly: label dir
foreach X in `r(names)' {
	label copy `X' s_`X'
	lab drop `X'
}

*This part attaches the renamed value labels to the variables
quietly: ds, has(vallabel)
foreach a of varlist `r(varlist)'{
	local b : value label `a'
	lab val `a' s_`b'
	}

*Rename 2004 variables which have an exact 2011 equivalent
rename a1 qa1
rename a2 qa2
rename a3 qa4
rename a3_dec qa4_dec
rename a6a qa5a
rename a6b qa5b
rename a6c qa5c
rename a7a qa7a
rename a7b qa7b
rename a7c qa7c
rename a7d qa7d
rename a7e qa7e
rename a8a qa8a
rename a8b qa8b
rename a8c qa8c
rename a8d qa8d
rename a8e qa8f
rename a8f qa8g
rename a8g qa8h
rename a9a qa9a
rename a9d qa9c
rename a9e qa9e
rename b4 qb3
rename b5 qb4
rename b6a qb6a
rename b6b qb6b
rename b6c qb6c
rename b6d qb6d
rename b8a qb7a
rename b8b qb7b
rename b8c qb7c
rename b9 qb8
rename c1a qc1b
rename c1b qc1c
rename c1c qc1d
rename c2a qc2a
rename c2b qc2b
rename c2c qc2c
rename c2d qc2d
rename c2e qc2e
rename c2f qc2f
rename c3 qc3
rename d1 qd1
rename d2a qd2a
rename d2b qd2c
rename d2c qd2d
rename d2d qd2e
rename d3 qd3
rename d5 qd4
rename d6a qd5a
rename d6b qd5b
rename d6c qd5c
rename e1 qe1
rename e2 qe2
rename e5 qe5
rename e7_1 qe7mul1
rename e7_2 qe7mul2
rename e7_3 qe7mul3
rename e7_4 qe7mul4
rename e7_5 qe7mul5
rename e7_6 qe7mul6
rename e7_7 qe7mul7
rename e7_8 qe7mul8
rename e8_1 qe7mul9
rename e8_2 qe7mul10
rename e8_3 qe7mul11
rename e8_4 qe7mul12
rename e8_5 qe7mul13
rename e8_6 qe7mul14
rename e8_7 qe7mul15
rename e8_8 qe7mul16
rename e8_9 qe7mul17
rename e13 qe10

sort serno
quietly: compress
save "$path_derived\mq&wrq&seq_2004_renamed.dta", replace

use "$path_derived\mq&wrq&seq_2011.dta", clear

*Rename 2011 overcode variables which have an exact 2004 equivalent
rename xcode10 xcode15
rename xcode11 xcode16
rename xcode12 xcode17
rename xcode13 xcode18

sort serno
quietly: compress
save "$path_derived\mq&wrq&seq_2011_renamed.dta", replace

*Append the 2011 data to the 2004 data and derive a year dummy (nyear)
use "$path_derived\mq&wrq&seq_2011_renamed.dta", clear
gen nyear=1

append using "$path_derived\mq&wrq&seq_2004_renamed.dta"
replace nyear=0 if nyear==.
lab var nyear "Observation year"
lab val nyear year

**************************************************************************************
*Define labels
**************************************************************************************
lab define year 0 "2004" 1 "2011"
label define yesno 1 "Yes" 0 "No" .e "Item not applicable"
lab define nsource 1 "2004 cross-section" 2 "2011 cross-section" 3 "2004 Panel" 4 "2011 Panel"

*The following variables can be used to select subsets of observations for individual datasets, but not to select pairs of matched respondents e.g. MQ and WRQ
*Derive a variable to select a single MQ observation for each workplace for each year (nmq)
bysort serno nyear: gen t=_n if serno<.
bysort w5serial nyear: gen t1=_n if serno>=.
gen nmq=0
replace nmq=1 if t==1
replace nmq=1 if serno>=. & w5serial<. & t1==1
lab val nmq yesno
lab var nmq "Selects single MQ observation per wp per year"
drop t t1

*Derive a variable to indicate the source of the data (nsource)
bysort serno: egen t=total(nmq)
gen nsource=1 if nyear==0 & t==1
replace nsource=2 if nyear==1 & t==1
replace nsource=3 if nyear==0 & t==2
replace nsource=4 if nyear==1 & t==2
lab val nsource nsource
lab var nsource "Source of data"
drop t

*Derive a variable to select a single WRQ observation for each worker rep for each year (nwrq)
bysort serno nyear wareptyp: gen t=_n if wareptyp<. & serno<.
bysort w5serial nyear wareptyp: gen t1=_n if serno==. & wareptyp<.
gen nwrq=0
replace nwrq=1 if t==1
replace nwrq=1 if t1==1 & serno==. & w5serial<.
lab var nwrq "Selects single WRQ observation per rep type per year"
lab val nwrq yesno

*Derive variable to select 2004 WRQ cases only (nwrq2004)
gen nwrq2004=0
replace nwrq2004=1 if nyear==0 & t==1
replace nwrq2004=1 if nyear==0 & t1==1
lab var nwrq2004 "2004 WRQ"
lab val nwrq2004 yesno

*Derive variable to select 2011 WRQ cases only (nwrq2011)
gen nwrq2011=0
replace nwrq2011=1 if nyear==1 & t==1
lab var nwrq2011 "2011 WRQ"
lab val nwrq2011 yesno
drop t t1

*Derive a variable to select 2004 MQ cases only (nmq2004)
gen nmq2004=0
replace nmq2004=1 if nmq==1 & nyear==0
lab var nmq2004 "2004 MQ"
lab val nmq2004 yesno

*Derive a variable to select 2011 MQ cases only (nmq2011)
gen nmq2011=0
replace nmq2011=1 if nmq==1 & nyear==1
lab var nmq2011 "2011 MQ"
lab val nmq2011 yesno

*Derive variable to select MQ panel cases only (npanel)
gen npanel=0
replace npanel=1 if nmq==1 & (nsource==3|nsource==4)
lab var npanel "MQ panel"
lab val npanel yesno

*Derive variable to identify PQ year (npayyr)
gsort serno -npanel nyear
by serno: gen npanyr=_n
replace npanyr=. if npanyr>2| npanel~=1
replace npanyr=0 if npanyr==1 
replace npanyr=1 if npanyr==2
lab var npanyr "2004 or 2011 panel case"
lab define npanyr 0 "2004 panel" 1 "2011 panel"
lab val npanyr npanyr

*Derive variable to select 2004 SEQ cases only (nseq2004)
bysort serno nyear persid: gen t=_n if serno<. & persid~=.
bysort w5serial nyear persid: gen t1=_n if serno==. & persid~=.
gen nseq2004=0
replace nseq2004=1 if nyear==0 & t==1
replace nseq2004=1 if nyear==0 & t1==1
lab var nseq2004 "2004 SEQ"
lab val nseq2004 yesno
drop t t1

*Derive variable to select 2011 SEQ cases only (nseq2011)
gen nseq2011=0
replace nseq2011=1 if nyear==1 & persid~=.
lab var nseq2011 "2011 SEQ"
lab val nseq2011 yesno

*Derive variable to select SEQ cases only (nseq)
gen nseq=0
replace nseq=1 if nseq2004==1|nseq2011==1
lab var nseq "Selects SEQ cases for 2004 and 2011"
lab val nseq yesno

*Identify all SEQ responses for panel wps where employees responded in both 2004 and 2011 (nseqpan)
sort serno nseq npanel
by serno: egen nseqpan=total(npanel)
replace nseqpan=1 if nseqpan==2
*Recode cases where only have SEQ responses for one year
replace nseqpan=.s if nseqpan==1 & nseq==0
bysort serno: egen t=total(nseqpan)
bysort serno: egen t1=total(npanel)
replace t1=1 if t1==2
bysort serno: egen t2=total(t1)
replace nseqpan=.s if t2>t
drop t t1 t2
lab val nseqpan nseqpan
lab define nseqpan 1 "Yes" 0 "No" .s "No SEQ responses for one or both years"
lab var nseqpan "Selects SEQ responses in panel workplaces where some SEQs in both years"

***********************************************
*Data fix
*D2: Syntax to account for different response categories in 2004 and 2011 
***********************************************

*D2: Syntax to account for different response categories in 2004 and 2011
*lab define ed2new 1 "Myself" 2 "Trade union" 3 "Employee rep (non-union)" 4 "Line manager" 5 "Another employee" 6 "Somebody else" .a "Refusal" .c "Multi-coded" .e "Item not applicable"
replace qd2a=6 if nseq2004==1 & qd2a==5
replace qd2c=6 if nseq2004==1 & qd2c==5
replace qd2d=6 if nseq2004==1 & qd2d==5
replace qd2e=6 if nseq2004==1 & qd2e==5
replace qd2a=5 if nseq2004==1 & qd2a==4
replace qd2c=5 if nseq2004==1 & qd2c==4
replace qd2d=5 if nseq2004==1 & qd2d==4
replace qd2e=5 if nseq2004==1 & qd2e==4
lab val qd2a ed2new 
lab val qd2c ed2new 
lab val qd2d ed2new 
lab val qd2e ed2new 

*LS - but issue with odd case on qd2a (why not recoded from 4 to 5, i.e. 1 case that appears under line manager?)
*See tab below
*Note this is also a problem in original syntax

ta qd2a nyear, m

***********************************************
* Here we copy panel weights across from the 2011 to the 2004 observations
*Before we used to do this earlier in this file by matching on relevant data files (old syntax below)
*But to avoid depositing separate data, just copy across from 2011 observations to 2004 observations

*MQ
sort serno
by serno: egen temp_pqwtnr=max(pqwtnr_apr13) if (nsource==3|nsource==4)
replace pqwtnr_apr13=temp_pqwtnr if pqwtnr_apr13==. & nsource==3
by serno: egen temp_pqempwtnr=max(pqempwtnr_apr13) if (nsource==3|nsource==4)
replace pqempwtnr_apr13=temp_pqempwtnr if pqempwtnr_apr13==. & nsource==3
drop temp_pqwtnr temp_pqempwtnr

*WRQ 
replace tuwtnrp_apr13=. if nwrq==0 | nyear==0
bysort serno: egen temp_tuwtnr=max(tuwtnrp_apr13) if (nsource==3|nsource==4) 
replace tuwtnrp_apr13=temp_tuwtnr if tuwtnrp_apr13==. & nsource==3 & nwrq==1 & (wareptyp==1|wareptyp==2)
replace tuwtnrp_apr13=temp_tuwtnr if tuwtnrp_apr13==. & nsource==4 & nwrq==1 & (wareptyp==1|wareptyp==2)
drop temp_tuwtnr

*SEQ: here we are concerned with the SEQ weight that is used to analyse SEQs that arise from panel workplaces
*that generated SEQs in both years (which could be used to look at changes in employee attitudes in panel workplaces)
* The weight for 2011 is already present on the deposited 2011 dataset (seqwtnrp_may13)
* Here we match on the weight for 2004 (which is not currently on the deposited dataset, as of 2nd Dec 13)
merge m:1 w5serial persid using "$path_extradata\WERS_2011_panel_weight_for_2004_SEQs.dta", nogen keep(master match) keepusing(new_seqwtnrp04)
replace seqwtnrp_may13=new_seqwtnrp04 if nseqpan==1 & nyear==0
drop new_seqwtnrp04

***********************************************
quietly: compress
save "$path_derived\mq&wrq&seq_2004&2011.dta", replace

*Erase files no longer needed
erase "$path_derived\xs04_mqv2_converted.dta"
erase "$path_derived\xs04_seqv2_converted.dta"
erase "$path_derived\xs04_erqv2_converted.dta"
erase "$path_derived\wers11_mq_general_use_missings_coded_numeric_July2013_converted.dta"
erase "$path_derived\wers11_seq_general_use_missings_coded_numeric_July2013_converted.dta"
erase "$path_derived\wers11_wrq_general_use_missings_coded_numeric_July2013_converted.dta"
erase "$path_derived\mq&wrq&seq_2004.dta"
erase "$path_derived\mq&wrq&seq_2011.dta"
erase "$path_derived\mq&wrq&seq_2004_renamed.dta"
erase "$path_derived\mq&wrq&seq_2011_renamed.dta"

log close


