*Setting up the WRQ

*********************************
*Syntax produced by the 2011 WERS Research Team
*********************************
clear all
set more off

capture log close
log using "$path_log\wrq_setup.log", replace

***********************************************
* Notes
***********************************************
*This file derives variables for the WRQ, as listed below 

*DV: Type of rep into 3 groups (w_reptyp3) BvW
*DV: Type of rep into 2 groups (w_reptyp2) BvW
*DV: Age of rep into 6 bands (w_age) BvW 
*DV: Ethnicity of rep (w_ethnic) BvW
*DV: Respondent is full-time representative (w_ftrep) BvW
*DV: Hours worked by rep (w_ftpt) BvW
*DV: Whether ft/pt and paid/unpaid on rep duties (w_ftptpay) BvW
*DV: Representative's occupation by higher or lower skill status (w_repsoc) BvW
*DV: Hours spent on representative duties by representatives - banded (w_hours, w_hours2) BvW
*DV: Number of years spent as a representative into 4 groups (w_yrsrep) BvW
*DV: Rep spent any time on rates of pay in the last 12 months (w_issue1) BvW
*DV: Rep spent any time on hours of work in the last 12 months (w_issue2) BvW
*DV: Rep spent any time on holiday entitlements in the last 12 months (w_issue3) BvW
*DV: Rep spent any time on pension entitlements in the last 12 months (w_issue4) BvW
*DV: Rep spent any time on recruitment or selection of employees in the last 12 months (w_issue5) BvW
*DV: Rep spent any time on training of employees in the last 12 months (w_issue6) BvW
*DV: Rep spent any time on disciplinary matters or grievances in the last 12 months (w_issue7) BvW
*DV: Rep spent any time on staffing levels in the last 12 months (w_issue8) BvW
*DV: Rep spent any time on equal opportunities in the last 12 months (w_issue9) BvW
*DV: Rep spent any time on health and safety in the last 12 months (w_issue10) BvW
*DV: Rep spent any time on performance appraisals in the last 12 months (w_issue11) BvW
*DV: Rep spent any time on terms and conditions in the last 12 months (w_isstc) BvW
*DV: Rep spent any time on selection, development or staffing in the last 12 months (w_isssds) BvW
*DV: Rep spent any time on welfare issues (equal opportunities and health and safety) in the last 12 months (w_issw) BvW
*DV: Rep spent any time on 'other' issues in the last 12 months (w_issoth) BvW
*NOTE: 2004 variable Xissid - rep spent time on individual disuptes is now equivalent to w_issue7 BvW
*DV: Most important issue dealt with in past year (w_impiss) BvW
*DV: Most important issue representative dealt with in past year - categories (w_impiss2) BvW
*DV: Number of issues rep involved in over past year, out of 12 (w_numiss, w_numiss2) BvW
*DV: Method of appointment - union reps & non-union reps(w_uselec, w_nusel) BvW
*DV: Relationship with managers - summary var (w_ratere) BvW
*DV: Summary of attitude/agreement vars (w_manclo, w_trust4) BvW 
*DV: Reps at the workplace that are of equivalent type to the interviewed rep (w_numrep, w_nreps6, w_nreps2) BvW
*DV: Number of employees (constituents) represented by reps, and density (w_numcon, w_repden, w_repden6) BvW
*DV: Number of employees (constituents) per rep (w_cpr, w_cpr5) BvW
*DV: Proportion of employees represented by rep that are female (w_propfe, w_propf3) BvW
*DV: Whether senior rep is representative of constituents in respect of gender (w_geneq) BvW 
*DV: Combined WRQ weight for 2004 and 2011 (w_wt) BvW
*DV: WRQ panel weight for workplaces with union rep interviews in both 2004 and 2011 (w_pqtuwt) JF
*DV: Dummy variables for union and non-union representative (w_urep, w_nurep) BvW
*DV: Relations between management and emp reps v/good (w_relat2) HB


***********************************************
*Open version of dataset which contains the MQ and SEQ derived variables
***********************************************

use "$path_derived\mq&seq_derived.dta", clear

***********************************************
*Define labels
***********************************************
/*Missing values
.a Refusal
.b Don't know
.c Multicoded
.d Schedule not applicable 
.e Item not applicable
.f Don't know or not answered
.g Refused or multi-coded
.h Refused, don't know or multicoded
.i Refusal, don't know, not applicable, multicoded
.j Negative
.k None
.l Don't know or item not applicable
.m Refused or item not applicable
*/

lab define w_ethnic 1 "White" 2	"Mixed" 3 "Black or Black British" 4 "Asian, arab or other" .a "Refused" .b "Don't know" .e "Item not applicable"
lab define w_ftpt 1 "Part-time (less than 30 hours per week)" 2 "Full-time (30 or more hours per week)" .a "Refusal" .b "Don't know" .e "Item not applicable" .k "None"
lab define w_yesno 1 "Yes" 0 "No" .a "Refusal" .b "Don't know" .e "Item not applicable" .f "Not answered"
lab define w_issues 1 "Rates of pay" 2 "Hours of work" 3 "Holiday entitlements" 4 "Pension entitlements" 5 "Recruitment or selection of employees" 6 "Training of employees" 7 "Disciplinary matters & grievances" 8 "Staffing levels" 9 "Equal opportunities" 10 "Health & safety" 11 "Performance appraisals" 95 "Other issues" 13 "None of these issues are important" 12 "staff absence or sickness" 14 "working practices" 15 "work-life balance arrangements" .a "Refusal" .b "Don't know" .e "Item not applicable" .f "Not answered"
lab define w_isscat 1 "Terms & Conditions" 2 "Staffing, selection & development" 3 "Individual disputes" 4 "Welfare (equal opps, H&S, absence" 5 "Other" 6 "None of these issues are important" .a "Refused" .b "Don't know" .e "Item not applicable" .f "Not answered"
label define w_ftptpay 1 "Paid full-time" 2	"Upaid full-time" 3	"Paid part-time" 4 "Unpaid part-time" .a "Refusal" .b "Don't know" .e "Item not applicable"
label define w_uselec 1 "Elected by union members" 2 "Selected by union members" 3 "Selected by union reps/officials" 4 "Selected by managers" 5 "No selection - volunteered" 6	"Other answer given" .a "Refusal" .b "Don't know" .e "Item not applicable"
label define w_nusel 1 "Elected by employees" 2	"Selected by employees" 3 "Selected by existing reps" 4 "Selected by managers" 5 "No selection - volunteered" 6	"Other answer given" .a "Refusal" .b "Don't know" .e "Item not applicable"
label define w_item .a "Refused" .b "Don't know" .e "Item not applicable" .f "Not answered - stand alone rep"
label define wrepcon 1 "Representative of at least 40% of constituents" 2 "Not representative" .a "Refused" .b "Don't know" .e "Item not applicable" 

******************************************
*REP CHARACTERISTICS
******************************************

*Recode type of rep into 3 groups
recode wareptyp (1/2=1 "Union rep") (3=2 "Non-union JCC rep") (4=3 "Non-union stand-alone rep") (.e=.e "Item not applicable"),ge(w_reptyp3)
label var w_reptyp3 "Type of worker representative"
ta w_reptyp3 nyear, mi

*Recode type of rep into 2 groups
recode wareptyp (1/2=1 "Union rep") (3/4=2 "Non-union rep") (.e=.e "Item not applicable"),ge(w_reptyp2)
label var w_reptyp2 "Type of worker representative"
ta w_reptyp2 nyear, mi

*Recode age of rep into 6 groups
recode wlage (16/20=1 "Less than 20 years") (20/29=2 "Between 20 and 29") (30/39=3 "Between 30 and 39") (40/49=4 "Between 40 and 49") (50/59=5 "Between 50 and 59") (60/90=6 "60 years or more") (.a=.a "Refused") (.b=.b "Don't know") (.e=.e "Item not applicable"),ge(w_age)
label var w_age "Respondents age"
ta w_age nyear, mi

*Recode ethnicity into 5 groups
gen w_ethnic = wlethnix
replace w_ethnic=1 if WLETHNIC>=1 & WLETHNIC<=3
replace w_ethnic=2 if WLETHNIC>=4 & WLETHNIC<=7
replace w_ethnic=3 if (WLETHNIC>=12 & WLETHNIC<=14) | (wlethnix==4)
replace w_ethnic=4 if (WLETHNIC>=8 & WLETHNIC<=11) | WLETHNIC==15 | WLETHNIC==16 | wlethnix==3 | wlethnix==5
replace w_ethnic=.a if WLETHNIC==.a
replace w_ethnic=.b if WLETHNIC==.b
replace w_ethnic=.e if WLETHNIC==.e
label var w_ethnic "Worker rep's ethnicity"
label val w_ethnic w_ethnic
ta w_ethnic nyear, mi

*Derive respondent is a full-time rep 
*I was unclear as to whether WAHOURS in 2004 referred to all hours - both paid job and rep work hence WAHRSALL replaced WAHOURS
*WAFULLTI in 2004 appears to have problems as some reporting to be full-time rep when WAHOURS > WHRSWRK
gen w_ftrep =0
replace w_ftrep=1 if WAHOURS<=wahrswrk & nyear==0
replace w_ftrep=1 if wahrsall<=wahrswrk & nyear==1
replace w_ftrep=.e if WAHOURS==.e | wahrswrk==.e | wahrsall==.e
replace w_ftrep=.a if WAHOURS==.a | wahrswrk==.a | wahrsall==.a
replace w_ftrep=.b if WAHOURS==.b | wahrswrk==.b | wahrsall==.b
label var w_ftrep "Full-time on rep duties"
label define w_ftrep 1 "Full-time rep" 0 "Part-time rep" .a "Refusal" .b "Don't know" .e "Item not applicable" 
label val w_ftrep w_ftrep
ta w_ftrep nyear, mi

*Recode hours worked by rep - full-time / part-time 
gen w_ftpt=0
replace w_ftpt=.e if WAHOURS==.e |wahrsall==.e
replace w_ftpt=1 if (WAHOURS>=1 & WAHOURS<=29) | (wahrsall>=1 & wahrsall<=29)
replace w_ftpt=2 if (WAHOURS>=30 & WAHOURS<.) | (wahrsall>=30 & wahrsall<.)
replace w_ftpt=.a if WAHOURS==.a |wahrsall==.a
replace w_ftpt=.b if WAHOURS==.b |wahrsall==.b
replace w_ftpt=.k if WAHOURS==0 | wahrsall==0
lab var w_ftpt "Hours worked by rep"
lab val w_ftpt w_ftpt
ta w_ftpt nyear, mi

*Derive whether ft/pt and paid/unpaid on rep duties 
gen w_ftptpay=0 
replace w_ftptpay=wapayhrs if w_ftrep==1
replace w_ftptpay=3 if w_ftrep==0 & wapayhrs==1
replace w_ftptpay=4 if w_ftrep==0 & wapayhrs==2
replace w_ftptpay=.e if w_ftrep==.e | wapayhrs==.e
replace w_ftptpay=.b if w_ftrep==.b | wapayhrs==.b
replace w_ftptpay=.a if w_ftrep==.a | wapayhrs==.a
label var w_ftptpay "Whether ft/pt and paid/unpaid on rep duties" 
label val w_ftptpay w_ftptpay
ta w_ftptpay nyear, mi

*Recode representative's occupation into higher or lower skill status 
*Note: changed variable name from Xlrepsoc2 in 04 to w_repsoc in 11
recode warepsoc (1/3=1 "Higher skill occupation") (5=1) (6/9=2 "Lower skill occupation") (4=2) (.a=.a "Refused") (.b=.b "Don't know") (.e=.e "Item not applicable"),ge(w_repsoc)
label var w_repsoc "Representative's occupation by higher or lower skill status"
ta w_repsoc nyear, mi

*Note: Variable identifying union reps masquerading as JCC reps (Xreptyp5) does not appear to be needed 
*In 04 all WBUNONLY=1 appear to have been recoded.

*Recode hours spent on representative duties by representatives - 5 bands
*Note: have changed categories based on decimal places in 2011 data.
recode wahrswrk (0=0 "Zero hours") (0.1/0.9=1 "Less than an hour") (1/1.9=2 "1 to <2 hrs") (2/4.9=3 "2 to <5 hrs") (5/9.9=4 "5 to <10 hrs") (10/120=5 "10 hrs or more") (.a=.a "Refused") (.b=.b "Don't know") (.e=.e "Item not applicable"), ge(w_hours)
replace w_hours=WAHRDK if WAHRDK>=1 & WAHRDK<=5
replace w_hours=1 if xcode18==11 | xcode18==12
label var w_hours "Hours rep spent on rep activities"
ta w_hours nyear, mi

*Recode hours spent on representative duties by representatives - 2 bands 
recode w_hours (0=0 "Zero hours") (1/3=1 "More than 0 to <5 hours")(4/5=2 "5 or more hours") (.a=.a "Refused") (.b=.b "Don't know") (.e=.e "Item not applicable"),ge(w_hours2)
label var w_hours2 "Hours rep spent on rep activities"
ta w_hours2 nyear, mi

*Recode number of years service as a worker representative.
*Note that in 2004 found that rep tenure was greater than job tenure. But job tenure deleted from 2011. 
recode warepyrs (0/1=1 "One year or less") (2/4=2 "Two to four years") (5/10=3 "Five to ten years") (11/99=4 "More than ten years") (.a=.a "Refused") (.b=.b "Don't know") (.e=.e "Item not applicable"),ge(w_yrsrep)
label var w_yrsrep "Number of years as rep at workplace"
ta w_yrsrep nyear, mi

**********
* ISSUES *
**********

*Derive rep spent time on rates of pay in last 12 months - binary
gen w_issue1 = 0
replace w_issue1=.e if WAPROT01==.e | waprwx01==.e
replace w_issue1=.b if WAPROT01==.b | waprwx01==.b
replace w_issue1=.a if WAPROT01==.a | waprwx01==.a
replace w_issue1=.f if WAPROT01==-7 
replace w_issue1=1 if inlist(WAPROT01,1) | inlist(WAPROT02,1) | inlist(WAPROT03,1) | inlist(WAPROT04,1) | inlist(WAPROT05,1) | inlist(WAPROT06,1) | inlist(WAPROT07,1) | inlist(WAPROT08,1) | inlist(WAPROT09,1) | inlist(WAPROT10,1) | inlist(WAPROT11,1) | inlist(WAPROT12,1) | inlist(WAPROT13,1) | inlist(XWAPROT1,1) | inlist(XWAPROT2,1) | inlist(XWAPROT3,1)  
replace w_issue1=1 if inlist(waprwx01,1) | inlist(waprwx02,1) | inlist(waprwx03,1) | inlist(waprwx04,1) | inlist(waprwx05,1) | inlist(waprwx06,1) | inlist(waprwx07,1) | inlist(waprwx08,1) | inlist(waprwx09,1) | inlist(waprwx10,1) | inlist(waprwx11,1) | inlist(waprwx12,1) | inlist(xwaprx01,1) | inlist(xwaprx02,1) | inlist(xwaprx03,1)  
label var w_issue1 "Rep spent time on rates of pay in last 12 months"
label values w_issue1 w_yesno
ta w_issue1 nyear, mi

*Derive rep spent time on hours of work in last 12 months - binary
gen w_issue2 = 0
replace w_issue2=.e if WAPROT01==.e | waprwx01==.e
replace w_issue2=.b if WAPROT01==.b | waprwx01==.b
replace w_issue2=.a if WAPROT01==.a | waprwx01==.a
replace w_issue2=.f if WAPROT01==-7 
replace w_issue2=1 if inlist(WAPROT01,2) | inlist(WAPROT02,2) | inlist(WAPROT03,2) | inlist(WAPROT04,2) | inlist(WAPROT05,2) | inlist(WAPROT06,2) | inlist(WAPROT07,2) | inlist(WAPROT08,2) | inlist(WAPROT09,2) | inlist(WAPROT10,2) | inlist(WAPROT11,2) | inlist(WAPROT12,2) | inlist(WAPROT13,2) | inlist(XWAPROT1,2) | inlist(XWAPROT2,2) | inlist(XWAPROT3,2)  
replace w_issue2=1 if inlist(waprwx01,2) | inlist(waprwx02,2) | inlist(waprwx03,2) | inlist(waprwx04,2) | inlist(waprwx05,2) | inlist(waprwx06,2) | inlist(waprwx07,2) | inlist(waprwx08,2) | inlist(waprwx09,2) | inlist(waprwx10,2) | inlist(waprwx11,2) | inlist(waprwx12,2) | inlist(xwaprx01,2) | inlist(xwaprx02,2) | inlist(xwaprx03,2)  
label var w_issue2 "Rep spent time on hours of work in last 12 months"
label values w_issue2 w_yesno
ta w_issue2 nyear, mi

*Derive rep spent time on holiday entitlements in last 12 months - binary
gen w_issue3 = 0
replace w_issue3=.e if WAPROT01==.e | waprwx01==.e
replace w_issue3=.b if WAPROT01==.b | waprwx01==.b
replace w_issue3=.a if WAPROT01==.a | waprwx01==.a
replace w_issue3=.f if WAPROT01==-7 
replace w_issue3=1 if inlist(WAPROT01,3) | inlist(WAPROT02,3) | inlist(WAPROT03,3) | inlist(WAPROT04,3) | inlist(WAPROT05,3) | inlist(WAPROT06,3) | inlist(WAPROT07,3) | inlist(WAPROT08,3) | inlist(WAPROT09,3) | inlist(WAPROT10,3) | inlist(WAPROT11,3) | inlist(WAPROT12,3) | inlist(WAPROT13,3) | inlist(XWAPROT1,3) | inlist(XWAPROT2,3) | inlist(XWAPROT3,3)  
replace w_issue3=1 if inlist(waprwx01,3) | inlist(waprwx02,3) | inlist(waprwx03,3) | inlist(waprwx04,3) | inlist(waprwx05,3) | inlist(waprwx06,3) | inlist(waprwx07,3) | inlist(waprwx08,3) | inlist(waprwx09,3) | inlist(waprwx10,3) | inlist(waprwx11,3) | inlist(waprwx12,3) | inlist(xwaprx01,3) | inlist(xwaprx02,3) | inlist(xwaprx03,3)  
label var w_issue3 "Rep spent time on holiday entitlements in last 12 months"
label values w_issue3 w_yesno
ta w_issue3 nyear, mi

*Derive rep spent time on pension entitlements in last 12 months - binary
gen w_issue4 = 0
replace w_issue4=.e if WAPROT01==.e | waprwx01==.e
replace w_issue4=.b if WAPROT01==.b | waprwx01==.b
replace w_issue4=.a if WAPROT01==.a | waprwx01==.a
replace w_issue4=.f if WAPROT01==-7 
replace w_issue4=1 if inlist(WAPROT01,4) | inlist(WAPROT02,4) | inlist(WAPROT03,4) | inlist(WAPROT04,4) | inlist(WAPROT05,4) | inlist(WAPROT06,4) | inlist(WAPROT07,4) | inlist(WAPROT08,4) | inlist(WAPROT09,4) | inlist(WAPROT10,4) | inlist(WAPROT11,4) | inlist(WAPROT12,4) | inlist(WAPROT13,4) | inlist(XWAPROT1,4) | inlist(XWAPROT2,4) | inlist(XWAPROT3,4)  
replace w_issue4=1 if inlist(waprwx01,4) | inlist(waprwx02,4) | inlist(waprwx03,4) | inlist(waprwx04,4) | inlist(waprwx05,4) | inlist(waprwx06,4) | inlist(waprwx07,4) | inlist(waprwx08,4) | inlist(waprwx09,4) | inlist(waprwx10,4) | inlist(waprwx11,4) | inlist(waprwx12,4) | inlist(xwaprx01,4) | inlist(xwaprx02,4) | inlist(xwaprx03,4)  
label var w_issue4 "Rep spent time on pension entitlements in last 12 months"
label values w_issue4 w_yesno
ta w_issue4 nyear, mi

*Derive rep spent time on recruitment or selection of employees in last 12 months - binary
gen w_issue5 = 0
replace w_issue5=.e if WAPROT01==.e | waprwx01==.e
replace w_issue5=.b if WAPROT01==.b | waprwx01==.b
replace w_issue5=.a if WAPROT01==.a | waprwx01==.a
replace w_issue5=.f if WAPROT01==-7 
replace w_issue5=1 if inlist(WAPROT01,5) | inlist(WAPROT02,5) | inlist(WAPROT03,5) | inlist(WAPROT04,5) | inlist(WAPROT05,5) | inlist(WAPROT06,5) | inlist(WAPROT07,5) | inlist(WAPROT08,5) | inlist(WAPROT09,5) | inlist(WAPROT10,5) | inlist(WAPROT11,5) | inlist(WAPROT12,5) | inlist(WAPROT13,5) | inlist(XWAPROT1,5) | inlist(XWAPROT2,5) | inlist(XWAPROT3,5)  
replace w_issue5=1 if inlist(waprwx01,5) | inlist(waprwx02,5) | inlist(waprwx03,5) | inlist(waprwx04,5) | inlist(waprwx05,5) | inlist(waprwx06,5) | inlist(waprwx07,5) | inlist(waprwx08,5) | inlist(waprwx09,5) | inlist(waprwx10,5) | inlist(waprwx11,5) | inlist(waprwx12,5) | inlist(xwaprx01,5) | inlist(xwaprx02,5) | inlist(xwaprx03,5)  
label var w_issue5 "Rep spent time on recruitment or selection in last 12 months"
label values w_issue5 w_yesno
ta w_issue5 nyear, mi

*Derive rep spent time on training of employees in last 12 months - binary
gen w_issue6 = 0
replace w_issue6=.e if WAPROT01==.e | waprwx01==.e
replace w_issue6=.b if WAPROT01==.b | waprwx01==.b
replace w_issue6=.a if WAPROT01==.a | waprwx01==.a
replace w_issue6=.f if WAPROT01==-7 
replace w_issue6=1 if inlist(WAPROT01,6) | inlist(WAPROT02,6) | inlist(WAPROT03,6) | inlist(WAPROT04,6) | inlist(WAPROT05,6) | inlist(WAPROT06,6) | inlist(WAPROT07,6) | inlist(WAPROT08,6) | inlist(WAPROT09,6) | inlist(WAPROT10,6) | inlist(WAPROT11,6) | inlist(WAPROT12,6) | inlist(WAPROT13,6) | inlist(XWAPROT1,6) | inlist(XWAPROT2,6) | inlist(XWAPROT3,6)  
replace w_issue6=1 if inlist(waprwx01,6) | inlist(waprwx02,6) | inlist(waprwx03,6) | inlist(waprwx04,6) | inlist(waprwx05,6) | inlist(waprwx06,6) | inlist(waprwx07,6) | inlist(waprwx08,6) | inlist(waprwx09,6) | inlist(waprwx10,6) | inlist(waprwx11,6) | inlist(waprwx12,6) | inlist(xwaprx01,6) | inlist(xwaprx02,6) | inlist(xwaprx03,6)  
label var w_issue6 "Rep spent time on training of employees in last 12 months"
label values w_issue6 w_yesno
ta w_issue6 nyear, mi

*Derive rep spent time on disciplinaries or grievances in last 12 months - binary
gen w_issue7 = 0
replace w_issue7=.e if WAPROT01==.e | waprwx01==.e
replace w_issue7=.b if WAPROT01==.b | waprwx01==.b
replace w_issue7=.a if WAPROT01==.a | waprwx01==.a
replace w_issue7=.f if WAPROT01==-7 
replace w_issue7=1 if inlist(WAPROT01,7,8) | inlist(WAPROT02,7,8) | inlist(WAPROT03,7,8) | inlist(WAPROT04,7,8) | inlist(WAPROT05,7,8) | inlist(WAPROT06,7,8) | inlist(WAPROT07,7,8) | inlist(WAPROT08,7,8) | inlist(WAPROT09,7,8) | inlist(WAPROT10,7,8) | inlist(WAPROT11,7,8) | inlist(WAPROT12,7,8) | inlist(WAPROT13,7,8) | inlist(XWAPROT1,7,8) | inlist(XWAPROT2,7,8) | inlist(XWAPROT3,7,8)  
replace w_issue7=1 if inlist(waprwx01,7) | inlist(waprwx02,7) | inlist(waprwx03,7) | inlist(waprwx04,7) | inlist(waprwx05,7) | inlist(waprwx06,7) | inlist(waprwx07,7) | inlist(waprwx08,7) | inlist(waprwx09,7) | inlist(waprwx10,7) | inlist(waprwx11,7) | inlist(waprwx12,7) | inlist(xwaprx01,7) | inlist(xwaprx02,7) | inlist(xwaprx03,7)  
label var w_issue7 "Rep spent time on disciplinaries or grievances in last 12 months"
label values w_issue7 w_yesno
ta w_issue7 nyear, mi

*Derive rep spent time on staffing levels in last 12 months - binary
gen w_issue8 = 0
replace w_issue8=.e if WAPROT01==.e | waprwx01==.e
replace w_issue8=.b if WAPROT01==.b | waprwx01==.b
replace w_issue8=.a if WAPROT01==.a | waprwx01==.a
replace w_issue8=.f if WAPROT01==-7 
replace w_issue8=1 if inlist(WAPROT01,9) | inlist(WAPROT02,9) | inlist(WAPROT03,9) | inlist(WAPROT04,9) | inlist(WAPROT05,9) | inlist(WAPROT06,9) | inlist(WAPROT07,9) | inlist(WAPROT08,9) | inlist(WAPROT09,9) | inlist(WAPROT10,9) | inlist(WAPROT11,9) | inlist(WAPROT12,9) | inlist(WAPROT13,9) | inlist(XWAPROT1,9) | inlist(XWAPROT2,9) | inlist(XWAPROT3,9)  
replace w_issue8=1 if inlist(waprwx01,8) | inlist(waprwx02,8) | inlist(waprwx03,8) | inlist(waprwx08,8) | inlist(waprwx05,8) | inlist(waprwx06,8) | inlist(waprwx07,8) | inlist(waprwx08,8) | inlist(waprwx09,8) | inlist(waprwx10,8) | inlist(waprwx11,8) | inlist(waprwx12,8) | inlist(xwaprx01,8) | inlist(xwaprx02,8) | inlist(xwaprx03,8)  
label var w_issue8 "Rep spent time on staffing levels in last 12 months"
label values w_issue8 w_yesno
ta w_issue8 nyear, mi

*Derive rep spent time on equal opportunities in last 12 months - binary
*Note that in 2011 "& diversity" was added to the code. 
gen w_issue9 = 0
replace w_issue9=.e if WAPROT01==.e | waprwx01==.e
replace w_issue9=.b if WAPROT01==.b | waprwx01==.b
replace w_issue9=.a if WAPROT01==.a | waprwx01==.a
replace w_issue9=.f if WAPROT01==-7 
replace w_issue9=1 if inlist(WAPROT01,10) | inlist(WAPROT02,10) | inlist(WAPROT03,10) | inlist(WAPROT04,10) | inlist(WAPROT05,10) | inlist(WAPROT06,10) | inlist(WAPROT07,10) | inlist(WAPROT08,10) | inlist(WAPROT09,10) | inlist(WAPROT10,10) | inlist(WAPROT11,10) | inlist(WAPROT12,10) | inlist(WAPROT13,10) | inlist(XWAPROT1,10) | inlist(XWAPROT2,10) | inlist(XWAPROT3,10)  
replace w_issue9=1 if inlist(waprwx01,9) | inlist(waprwx02,9) | inlist(waprwx03,9) | inlist(waprwx04,9) | inlist(waprwx05,9) | inlist(waprwx06,9) | inlist(waprwx07,9) | inlist(waprwx08,9) | inlist(waprwx09,9) | inlist(waprwx10,9) | inlist(waprwx11,9) | inlist(waprwx12,9) | inlist(xwaprx01,9) | inlist(xwaprx02,9) | inlist(xwaprx03,9)  
label var w_issue9 "Rep spent time on equal opportunities in last 12 months"
label values w_issue9 w_yesno
ta w_issue9 nyear, mi

*Derive rep spent time on health and safety in last 12 months - binary
gen w_issue10 = 0
replace w_issue10=.e if WAPROT01==.e | waprwx01==.e
replace w_issue10=.b if WAPROT01==.b | waprwx01==.b
replace w_issue10=.a if WAPROT01==.a | waprwx01==.a
replace w_issue10=.f if WAPROT01==-7 
replace w_issue10=1 if inlist(WAPROT01,11) | inlist(WAPROT02,11) | inlist(WAPROT03,11) | inlist(WAPROT04,11) | inlist(WAPROT05,11) | inlist(WAPROT06,11) | inlist(WAPROT07,11) | inlist(WAPROT08,11) | inlist(WAPROT09,11) | inlist(WAPROT10,11) | inlist(WAPROT11,11) | inlist(WAPROT12,11) | inlist(WAPROT13,11) | inlist(XWAPROT1,11) | inlist(XWAPROT2,11) | inlist(XWAPROT3,11)  
replace w_issue10=1 if inlist(waprwx01,10) | inlist(waprwx02,10) | inlist(waprwx03,10) | inlist(waprwx04,10) | inlist(waprwx05,10) | inlist(waprwx06,10) | inlist(waprwx07,10) | inlist(waprwx08,10) | inlist(waprwx09,10) | inlist(waprwx10,10) | inlist(waprwx11,10) | inlist(waprwx12,10) | inlist(xwaprx01,10) | inlist(xwaprx02,10) | inlist(xwaprx03,10)  
label var w_issue10 "Rep spent time on health & safety in last 12 months"
label values w_issue10 w_yesno
ta w_issue10 nyear, mi

*Derive rep spent time on performance appraisals in last 12 months - binary
gen w_issue11 = 0
replace w_issue11=.e if WAPROT01==.e | waprwx01==.e
replace w_issue11=.b if WAPROT01==.b | waprwx01==.b
replace w_issue11=.a if WAPROT01==.a | waprwx01==.a
replace w_issue10=.f if WAPROT01==-7 
replace w_issue11=1 if inlist(WAPROT01,12) | inlist(WAPROT02,12) | inlist(WAPROT03,12) | inlist(WAPROT04,12) | inlist(WAPROT05,12) | inlist(WAPROT06,12) | inlist(WAPROT07,12) | inlist(WAPROT08,12) | inlist(WAPROT09,12) | inlist(WAPROT10,12) | inlist(WAPROT11,12) | inlist(WAPROT12,12) | inlist(WAPROT13,12) | inlist(XWAPROT1,12) | inlist(XWAPROT2,12) | inlist(XWAPROT3,12)  
replace w_issue11=1 if inlist(waprwx01,11) | inlist(waprwx02,11) | inlist(waprwx03,11) | inlist(waprwx04,11) | inlist(waprwx05,11) | inlist(waprwx06,11) | inlist(waprwx07,11) | inlist(waprwx08,11) | inlist(waprwx09,11) | inlist(waprwx10,11) | inlist(waprwx11,11) | inlist(waprwx12,11) | inlist(xwaprx01,11) | inlist(xwaprx02,11) | inlist(xwaprx03,11)  
label var w_issue11 "Rep spent time on performance appraisals in last 12 months"
label values w_issue11 w_yesno
ta w_issue11 nyear, mi

*Derive rep spent any time on terms and conditions in the last 12 months 
gen w_isstc =0
replace w_isstc=.e if WAPROT01==.e | waprwx01==.e
replace w_isstc=.b if WAPROT01==.b | waprwx01==.b
replace w_isstc=.a if WAPROT01==.a | waprwx01==.a
replace w_isstc=.f if WAPROT01==-7 
replace w_isstc=1 if inlist(WAPROT01,1,2,3,4) | inlist(WAPROT02,1,2,3,4) | inlist(WAPROT03,1,2,3,4) | inlist(WAPROT04,1,2,3,4) | inlist(WAPROT05,1,2,3,4) | inlist(WAPROT06,1,2,3,4) | inlist(WAPROT07,1,2,3,4) | inlist(WAPROT08,1,2,3,4) | inlist(WAPROT09,1,2,3,4) | inlist(WAPROT10,1,2,3,4) | inlist(WAPROT11,1,2,3,4) | inlist(WAPROT12,1,2,3,4) | inlist(WAPROT13,1,2,3,4) | inlist(XWAPROT1,1,2,3,4) | inlist(XWAPROT2,1,2,3,4) | inlist(XWAPROT3,1,2,3,4)  
replace w_isstc=1 if inlist(waprwx01,1,2,3,4) | inlist(waprwx02,1,2,3,4) | inlist(waprwx03,1,2,3,4) | inlist(waprwx04,1,2,3,4) | inlist(waprwx05,1,2,3,4) | inlist(waprwx06,1,2,3,4) | inlist(waprwx07,1,2,3,4) | inlist(waprwx08,1,2,3,4) | inlist(waprwx09,1,2,3,4) | inlist(waprwx10,1,2,3,4) | inlist(waprwx11,1,2,3,4) | inlist(waprwx12,1,2,3,4) | inlist(xwaprx01,1,2,3,4) | inlist(xwaprx02,1,2,3,4) | inlist(xwaprx03,1,2,3,4)  
label var w_isstc "Rep spent time on terms and conditions in last 12 months"
label values w_isstc w_yesno
ta w_isstc nyear, mi

*Derive rep spent any time on staffing, development or selection in the last 12 months 
*Note this variable includes back-code 15=working practices 
gen w_isssds =0
replace w_isssds=.e if WAPROT01==.e | waprwx01==.e
replace w_isssds=.b if WAPROT01==.b | waprwx01==.b
replace w_isssds=.a if WAPROT01==.a | waprwx01==.a
replace w_isssds=.f if WAPROT01==-7 
replace w_isssds=1 if inlist(WAPROT01,5,6,9,12,15) | inlist(WAPROT02,5,6,9,12,15) | inlist(WAPROT03,5,6,9,12,15) | inlist(WAPROT04,5,6,9,12,15) | inlist(WAPROT05,5,6,9,12,15) | inlist(WAPROT06,5,6,9,12,15) | inlist(WAPROT07,5,6,9,12,15) | inlist(WAPROT08,5,6,9,12,15) | inlist(WAPROT09,5,6,9,12,15) | inlist(WAPROT10,5,6,9,12,15) | inlist(WAPROT11,5,6,9,12,15) | inlist(WAPROT12,5,6,9,12,15) | inlist(WAPROT13,5,6,9,12,15) | inlist(XWAPROT1,5,6,9,12,15) | inlist(XWAPROT2,5,6,9,12,15) | inlist(XWAPROT3,5,6,9,12,15)  
replace w_isssds=1 if inlist(waprwx01,5,6,8,11,14) | inlist(waprwx02,5,6,8,11,14) | inlist(waprwx03,5,6,8,11,14) | inlist(waprwx04,5,6,8,11,14) | inlist(waprwx05,5,6,8,11,14) | inlist(waprwx06,5,6,8,11,14) | inlist(waprwx07,5,6,8,11,14) | inlist(waprwx08,5,6,8,11,14) | inlist(waprwx09,5,6,8,11,14) | inlist(waprwx10,5,6,8,11,14) | inlist(waprwx11,5,6,8,11,14) | inlist(waprwx12,5,6,8,11,14) | inlist(xwaprx01,5,6,8,11,14) | inlist(xwaprx02,5,6,8,11,14) | inlist(xwaprx03,5,6,8,11,14)  
label var w_isssds "Rep spent time on staffing, development or selection in last 12 months"
label values w_isssds w_yesno
ta w_isssds nyear, mi

*NOTE: 2004 variable Xissid - rep spent time on individual disuptes is now equivalent to w_issue7

*Derive rep spent any time on welfare issues (equal opportunities, health and safety or absence/sickness) in the last 12 months 
*NOTE: have included back-code 16=work-life balance issues. In 2004 it wasn't included due to no label. 
gen w_issw=0
replace w_issw=.e if WAPROT01==.e | waprwx01==.e
replace w_issw=.b if WAPROT01==.b | waprwx01==.b
replace w_issw=.a if WAPROT01==.a | waprwx01==.a
replace w_issw=.f if WAPROT01==-7 
replace w_issw=1 if inlist(WAPROT01,10,11,14,16) | inlist(WAPROT02,10,11,14,16) | inlist(WAPROT03,10,11,14,16) | inlist(WAPROT04,10,11,14,16) | inlist(WAPROT05,10,11,14,16) | inlist(WAPROT06,10,11,14,16) | inlist(WAPROT07,10,11,14,16) | inlist(WAPROT08,10,11,14,16) | inlist(WAPROT09,10,11,14,16) | inlist(WAPROT10,10,11,14,16) | inlist(WAPROT11,10,11,14,16) | inlist(WAPROT12,10,11,14,16) | inlist(WAPROT13,10,11,14,16) | inlist(XWAPROT1,10,11,14,16) | inlist(XWAPROT2,10,11,14,16) | inlist(XWAPROT3,10,11,14,16)  
replace w_issw=1 if inlist(waprwx01,9,10,13,15) | inlist(waprwx02,9,10,13,15) | inlist(waprwx03,9,10,13,15) | inlist(waprwx04,9,10,13,15) | inlist(waprwx05,9,10,13,15) | inlist(waprwx06,9,10,13,15) | inlist(waprwx07,9,10,13,15) | inlist(waprwx08,9,10,13,15) | inlist(waprwx09,9,10,13,15) | inlist(waprwx10,9,10,13,15) | inlist(waprwx11,9,10,13,15) | inlist(waprwx12,9,10,13,15) | inlist(xwaprx01,9,10,13,15) | inlist(xwaprx02,9,10,13,15) | inlist(xwaprx03,9,10,13,15)  
label var w_issw "Rep spent time on welfare (equal opp, H&S, absence, W-L balance) in last 12 months"
label values w_issw w_yesno
ta w_issw nyear, mi

*Whether representative spent any time on 'other' issues in the last 12 months
gen w_issoth=0
replace w_issoth=.e if WAPROT01==.e | waprwx01==.e
replace w_issoth=.b if WAPROT01==.b | waprwx01==.b
replace w_issoth=.a if WAPROT01==.a | waprwx01==.a
replace w_issoth=.f if WAPROT01==-7 
replace w_issoth=1 if inlist(XWAPROT1,95) | inlist(XWAPROT2,95) | inlist(XWAPROT3,95)  
replace w_issoth=1 if inlist(xwaprx01,95) | inlist(xwaprx02,95) | inlist(xwaprx03,95)  
label var w_issoth "Rep spent time on other issues in last 12 months"
label values w_issoth w_yesno
ta w_issoth nyear, mi

*Derived Most important issue dealt with in past year 
*Note: have changed from 2004 variable to incorporate back-coding where there is multiple back-codes have taken the first one. 
gen w_impiss =waprmx
replace w_impiss =WAPROTIM if WAPROTIM>=1 & WAPROTIM<=7
replace w_impiss =WAPROTIM- 1 if WAPROTIM>=8 & WAPROTIM<=16 
replace w_impiss =XWAPROT1 if WAPROTIM==13 & XWAPROT1 >=1 & XWAPROT1 <=7
replace w_impiss =XWAPROT1 - 1 if WAPROTIM==13 & XWAPROT1 >=8 & XWAPROT1 <=16 
replace w_impiss =95 if WAPROTIM==13 & XWAPROT1 ==95
replace w_impiss =.f if WAPROTIM==13 & XWAPROT1==96
replace w_impiss =12 if WAPROTIM==13 & XWAPROT1 ==14
replace w_impiss =.f if WAPROTIM==-7
replace w_impiss =.b if WAPROTIM==.b
replace w_impiss =.a if WAPROTIM==.a
replace w_impiss =.b if WAPROTIM==.e & WAPROT01 ==.b
replace w_impiss =.a if WAPROTIM==.e & WAPROT01 ==.a
replace w_impiss =WAPROT01 if WAPROT01 >=1 & WAPROT01 <=7 & WAPROTIM==.e
replace w_impiss =WAPROT01 -1 if WAPROT01 >=8 & WAPROT01 <=16 & WAPROTIM==.e
replace w_impiss =XWAPROT1 if WAPROT01==13 & XWAPROT1 >=1 & XWAPROT1 <=7 & WAPROTIM==.e
replace w_impiss =XWAPROT1 - 1 if WAPROT01==13 & XWAPROT1 >=8 & XWAPROT1 <=16 & WAPROTIM==.e
replace w_impiss =95 if WAPROT01==13 & XWAPROT1 ==95 & WAPROTIM==.e
replace w_impiss =.f if WAPROT01==13 & XWAPROT1==96 & WAPROTIM==.e
replace w_impiss =12 if WAPROT01==13 & XWAPROT1 ==14 & WAPROTIM==.e
replace w_impiss =xwaprx01 if waprmx==12
replace w_impiss =12 if waprmx==12 & xwaprx01==13
replace w_impiss =95 if waprmx==12 & xwaprx01==95
replace w_impiss =.f if waprmx==12 & xwaprx01==96
replace w_impiss =waprwx01 if waprmx==.e
label var w_impiss "Most important issue dealt with in past year"
label values w_impiss w_issues
ta w_impiss nyear, mi

*Derived most important issue representative dealt with in past year - categories 
*NOTE: Still need to decide where to put back-code 15=work-life balance issues. In 2004 it wasn't included due to no label. 
gen w_impis2=0
replace w_impis2=1 if w_impiss >=1 & w_impiss <=4
replace w_impis2=2 if w_impiss ==5 | w_impiss ==6 | w_impiss ==8 | w_impiss ==11 | w_impiss ==14
replace w_impis2=3 if w_impiss ==7
replace w_impis2=4 if w_impiss ==9 | w_impiss ==10 | w_impiss ==12 | w_impiss ==15 
replace w_impis2=5 if w_impiss ==95
replace w_impis2=6 if w_impiss ==13
replace w_impis2=.a if w_impiss ==.a
replace w_impis2=.b if w_impiss ==.b
replace w_impis2=.e if w_impiss ==.e
replace w_impis2=.f if w_impiss ==.f
label var w_impis2 "Most important issue dealt with in past year - categories"
label values w_impis2 w_isscat
ta w_impis2 nyear, mi

*Number of issues rep involved in over past year, out of 11 
egen w_numiss=anycount(w_issue1 w_issue2 w_issue3 w_issue4 w_issue5 w_issue6 w_issue7 w_issue8 w_issue9 w_issue10 w_issue11), values(1)
replace w_numiss=w_issue1 if w_issue1==.a | w_issue1==.b | w_issue1==.e | w_issue1==.f
label var w_numiss "Number of issues rep has spent time on in last 12 months"
label val w_numiss nitem
ta w_numiss nyear, mi

*Number of issues representative involved in banded
*Note: variable was called 'Xnumiss2' in 04 and values have changed for corresponding labels (labels the same).
recode w_numiss (0=0 "No issues") (1=1 "1 issue") (2/5=2 "2 to 5 issues") (6/9=3 "6 to 9 issues") (10/12=4 "10 or more issues") (.a=.a "Refused") (.b=.b "Don't know") (.e=.e "Item not applicable"),ge(w_numis2)
label var w_numis2 "Number of issues rep has spent time on in last 12 months - banded"
ta w_numis2 nyear, mi

*Method of appointment - union reps 
*Note: var was called Xuselec in 2004
*Note: var no longer includes back-coding as 'other specify' option not available in 2011
egen w_uselec=anymatch(wbselec1 wbselec2 wbselec3 wbselec4), values (2,3)
replace w_uselec=3 if w_uselec==1
replace w_uselec=6 if w_uselec~=3 & wbselec1>=1 & wbselec1<=6
egen w_usele2=anymatch(wbselec1 wbselec2 wbselec3 wbselec4), values (1)
replace w_uselec=2 if w_usele2==1
replace w_uselec=5 if wbselec1==5 | wbselec2==5 | wbselec3==5 | wbselec4==5
replace w_uselec=4 if wbselec1==4 | wbselec2==4 | wbselec3==4 | wbselec4==4
drop w_usele2 
replace w_uselec=1 if wbelect==1 
replace w_uselec=.e if wbelect==.e 
replace w_uselec=.b if wbelect==.b | wbselec1 ==.b
replace w_uselec=.a if wbelect==.a | wbselec1 ==.a
label var w_uselec "Method of appointment - union reps" 
label val w_uselec w_uselec
ta w_uselec nyear, mi
 
*DV: Method of appointment - non-union reps 
*Note: Variable was called 'Xnuselec' in 2004
*Note: var no longer includes back-coding as 'other specify' option not available in 2011
gen w_nusel=0
replace w_nusel=6 if (wbselre1>=1 & wbselre1<=6) | (WCSELRE1>=1 & WCSELRE1<=6)
replace w_nusel=3 if wbselre1==2 | wbselre2==2 | wbselre3==2 | WCSELRE1==2 | WCSELRE2==2 | WCSELRE3==2
replace w_nusel=2 if wbselre1==1 | wbselre2==1 | wbselre3==1 | WCSELRE1==1 | WCSELRE2==1 | WCSELRE3==1
replace w_nusel=5 if wbselre1==4 | wbselre2==4 | wbselre3==4 | WCSELRE1==4 | WCSELRE2==4 | WCSELRE3==4
replace w_nusel=4 if wbselre1==3 | wbselre2==3 | wbselre3==3 | WCSELRE1==3 | WCSELRE2==3 | WCSELRE3==3
replace w_nusel=1 if wbhowrep==1 | WCHOWREP==1 
replace w_nusel=.e if wbhowrep==.e | WCHOWREP==.e
replace w_nusel=.b if wbhowrep==.b | wbselre1 ==.b | WCHOWREP==.b | WCSELRE1 ==.b
replace w_nusel=.a if wbhowrep==.a | wbselre1 ==.a | WCHOWREP==.a | WCSELRE1 ==.a
label var w_nusel "Method of appointment - non-union reps" 
label val w_nusel w_nusel
ta w_nusel nyear, mi

*Recode relationship with managers - summary var
recode whratere (1/2=1 "Good") (3=2 "Neither good nor poor") (4/5=3 "Poor") (.a=.a "Refused") (.b=.b "Don't know") (.e=.e "Item not applicable"), ge(w_ratere)
label var w_ratere "Rep's rating of reps and management relationship - 3 bands" 
ta w_ratere nyear, mi

*Recode attitude vars - summary vars (w_manclo, w_trust4) 
recode wemanclo (1/2=1 "Agree") (3=2 "Neither agree nor disagree") (4/5=3 "Disagree") (.a=.a "Refused") (.b=.b "Don't know") (.e=.e "Item not applicable"), ge(w_manclo)
recode whtrust4 (1/2=1 "Agree") (3=2 "Neither agree nor disagree") (4/5=3 "Disagree") (.a=.a "Refused") (.b=.b "Don't know") (.e=.e "Item not applicable"), ge(w_trust4)
label var w_manclo "Reps work closely with managers when changes are being introduced - 3 bands" 
label var w_trust4 "Reps trust managers to act with honest and integrity in there dealings with them - 3 bands" 
ta w_manclo nyear, mi
ta w_trust4 nyear, mi

******************
* REPRESENTATION *
******************

* Number of reps at the workplace of the equivalent type to the interviewed rep, including the interviewed rep
* Note that, for JCC reps, this counts the total number of reps on the JCC (union + non-union) as WCJCCNUM does not distinguish between the two. 
* One might expect that this should be 1 for all cases where the rep interview derives from Estewext (Xreptyp6=2), 
* but there could be multiple off-site reps who represent members at the sampled workplace (Estewext says 'any representatives or stewards' (plural)
* 2011: Deleted WCNUNUM - so not able to determine number of other SA reps at the workplace so they have to be excluded from this var.
* Will create a new variable that includes SA rep. 
gen w_numrep =-1
replace w_numrep=.e if wareptyp<=2 & (WBNUMREP==.e | wbrepnum==.e)
replace w_numrep=.b if wareptyp<=2 & (WBNUMREP==.b | wbrepnum==.b)
replace w_numrep=.a if wareptyp<=2 & (WBNUMREP==.a | wbrepnum==.a)
replace w_numrep=1 if wareptyp<=2 & (WBNUMREP==2 | wbrepnum==0)
replace w_numrep=wbrepnum + 1 if wareptyp<=2 & (wbrepnum>0 & wbrepnum <97)
replace w_numrep=.e if wareptyp==3 & wcjccnum==.e
replace w_numrep=.b if wareptyp==3 & wcjccnum==.b
replace w_numrep=.a if wareptyp==3 & wcjccnum==.a
replace w_numrep=wcjccnum + 1 if wareptyp==3 & (wcjccnum>=0 & wcjccnum <97)
replace w_numrep=.f if wareptyp==4 
replace w_numrep=1 if wareptyp==4 & (WCNUOTH==2 | wbnuoth==2)
replace w_numrep=WCNUNUM+1 if wareptyp==4 & WCNUNUM>=1 & WCNUNUM<97
label var w_numrep "Number of reps same as respondent type at the workplace"
label val w_numrep w_item
ta w_numrep nyear, mi

*Recode number of reps at the workplace of the equivalent type to the interviewed rep, including the interviewed rep 
*Note: Variable was called Xnumreps6 in 2004
recode w_numrep (5/9=5 "5-9") (10/96=6 "10 or more"), copyrest gen(w_nreps6)
label var w_nreps6 "Number of reps same as respondent type at the workplace - banded"
ta w_nreps6 nyear, mi

*Variable indicating whether other reps of same type at the workplace - to include all standalone reps
ge w_nreps2=-1
replace w_nreps2=.b if wareptyp<=2 & WBNUMREP==.e & nyear==0
replace w_nreps2=.b if wareptyp<=2 & wbrepnum==.e & nyear==1
replace w_nreps2=.b if wareptyp<=2 & WBNUMREP==.b & nyear==0
replace w_nreps2=.b if wareptyp<=2 & wbrepnum==.b & nyear==1
replace w_nreps2=.a if wareptyp<=2 & WBNUMREP==.a & nyear==0
replace w_nreps2=.a if wareptyp<=2 & wbrepnum==.a & nyear==1
replace w_nreps2=1 if wareptyp<=2 & (wbrepnum>0 & wbrepnum <97)
replace w_nreps2=1 if wareptyp<=2 & WBNUMREP==1
replace w_nreps2=0 if wareptyp<=2 & (WBNUMREP==2 | wbrepnum==0)
replace w_nreps2=.e if wareptyp==3 & wcjccnum==.e
replace w_nreps2=.b if wareptyp==3 & wcjccnum==.b
replace w_nreps2=.a if wareptyp==3 & wcjccnum==.a
replace w_nreps2=1 if wareptyp==3 & (wcjccnum>0 & wcjccnum <97)
replace w_nreps2=0 if wareptyp==3 & wcjccnum==0 
replace w_nreps2=.e if wareptyp==4 & (WCNUOTH==.e | wbnuoth==.e)
replace w_nreps2=.b if wareptyp==4 & (WCNUOTH==.b | wbnuoth==.b)
replace w_nreps2=.a if wareptyp==4 & (WCNUOTH==.a | wbnuoth==.a)
replace w_nreps2=0 if wareptyp==4 & (WCNUOTH==2 | wbnuoth==2)
replace w_nreps2=1 if wareptyp==4 & (WCNUOTH==1 | wbnuoth==1)
label var w_nreps2 "Other reps same as respondent type at the workplace"
label val w_nreps2 nyesno
ta w_nreps2 nyear, mi

*Number of employees (constituents) represented by rep, and density 
*Added a line to = missing where number of members represented is greater than zallemps
ge w_numcon=-1
replace w_numcon=wbpropme if w_reptyp2==1
replace w_numcon=zallemps*wbproppc/100 if w_reptyp2==1 & wbproppc>0 & wbproppc <=100
replace w_numcon=wcpropme if w_reptyp2==2
replace w_numcon=zallemps*wcproppc/100 if w_reptyp2==2 & wcproppc>0 & wcproppc <=100
replace w_numcon=.e if wbpropme>zallemps & wbpropme < .
replace w_numcon=.e if wcpropme>zallemps & wcpropme < .
label var w_numcon "Number of employees (constituents) represented by the rep (and colleagues)"
label val w_numcon nitem
by nyear, sort:su w_numcon

*Note: variable was called Xdensity in 2004
*Added a line to = missing where number of members represented is greater than zallemps
ge w_repden=-1
replace w_repden=wbpropme/zallemps*100 if w_reptyp2==1
replace w_repden=wcpropme/zallemps*100 if w_reptyp2==2
replace w_repden=w_numcon if w_numcon>=.a & w_numcon<=.f
replace w_repden=wbproppc if wbproppc>0 & wbproppc <=100
replace w_repden=wcproppc if wcproppc>0 & wcproppc <=100
replace w_repden=.e if wbpropme>zallemps & wbpropme < .
replace w_repden=.e if wcpropme>zallemps & wcpropme < .
replace w_repden=round(w_repden) if w_repden>0 & w_repden <100
label var w_repden "Proportion of employees represented by the rep (and colleagues)"
label val w_repden nitem
by nyear, sort:su w_repden

recode w_repden (0/19.49999=1 "0-19%") (19.50000/39.49999=2 "20-39%") (39.50000/59.49999=3 "40-59%") (59.50000/79.49999=4 "60-79%") (79.50000/99.49999=5 "80-99%") (99.50000/100=6 "100%"), copyrest gen(w_repden6)
lab var w_repden6 "Proportion of employees represented by rep - banded"
ta w_repden6 nyear, mi

*Number of constituents per rep 
*Added a  line to = missing where number of reps is greater than constituents
gen w_cpr=-1
replace w_cpr=w_numcon/w_numrep if w_numcon>0 & w_numrep>0
replace w_cpr=round(w_cpr) if w_cpr>0 
replace w_cpr=.e if w_numrep>w_numcon
replace w_cpr=w_numcon if w_numcon > .
replace w_cpr=w_numrep if w_numrep > .
label var w_cpr "Number of constituents per rep"
label val w_cpr nitem
ta w_cpr nyear, mi

recode w_cpr (100/10000=5 "100 or more") (50/99=4 "50-99") (25/49=3 "25-49") (10/25=2 "10-24") (0/10=1 "Less than 10"), copyrest ge(w_cpr5)
label var w_cpr5 "Number of constituents per rep - banded"
ta w_cpr5 nyear, mi

* Proportion of employees represented by rep that are female
* Please note the Q about proportion of employees represented by rep that are part-time was deleted in 2011.
gen w_propfe =wbpropfe
replace w_propfe =WCPROPFE if wareptyp>=3 & nyear==0
replace w_propfe=1 if w_propfe>=.a & w_propfe<=.f & w_repden==100 & nfemprop==1
replace w_propfe=2 if w_propfe>=.a & w_propfe<=.f & w_repden==100 & (nfemprop<1 & nfemprop>=0.8)
replace w_propfe=3 if w_propfe>=.a & w_propfe<=.f & w_repden==100 & (nfemprop<0.8 & nfemprop>=0.6)
replace w_propfe=4 if w_propfe>=.a & w_propfe<=.f & w_repden==100 & (nfemprop<06 & nfemprop>=0.4)
replace w_propfe=5 if w_propfe>=.a & w_propfe<=.f & w_repden==100 & (nfemprop<0.4 & nfemprop>=0.2)
replace w_propfe=6 if w_propfe>=.a & w_propfe<=.f & w_repden==100 & (nfemprop<0.2 & nfemprop>0)
replace w_propfe=7 if w_propfe>=.a & w_propfe<=.f & w_repden==100 & nfemprop==0
label var w_propfe "Proportion of employees represented by rep (& colleagues) that are female" 
label val w_propfe pcband
ta w_propfe nyear, mi

recode w_propfe (1/3=1 "Female-dominated (60-100%)") (4=2 "Balanced (40-59%)") (5/7=3 "Male-dominated (0-39%)"), copyrest ge(w_propf3)
label var w_propf3 "Proportion of employees represented by rep (& colleagues) that are female - summary" 
ta w_propf3 nyear, mi

* Whether rep is representative of constiutents in respect of gender 
gen w_geneq =w_propfe
replace w_geneq =wlrepgen if wlrepgen>=.a & wlrepgen<=.f 
replace w_geneq=1 if wlrepgen==1 & w_propfe>=4 & w_propfe<=7
replace w_geneq=1 if wlrepgen==2 & w_propfe>=1 & w_propfe<=4
replace w_geneq=2 if wlrepgen==1 & w_propfe>=1 & w_propfe<=3
replace w_geneq=2 if wlrepgen==2 & w_propfe>=5 & w_propfe<=7
label var w_geneq "Whether senior rep is representative in respect of gender"
label val w_geneq wrepcon 
ta w_geneq nyear, mi

**********************************
* RECESSION AND WORKPLACE CHANGE *
**********************************

*Representative reports at least one of 7 workplace changes occurring in the last 2 years, 2011
ge w_change=0
replace w_change=.b if wgemprx1==.b
replace w_change=.e if wgemprx1==.e
replace w_change=1 if inlist(wgemprx1,1,2,3,4,5,6)|inlist(wgemprx2,1,2,3,4,5,6)|inlist(wgemprx3,1,2,3,4,5,6)|inlist(wgemprx4,1,2,3,4,5,6)|inlist(wgemprx5,1,2,3,4,5,6)|inlist(wgemprx6,1,2,3,4,5,6)
replace w_change=1 if inlist(xwgempx1,1,2,3,4,5,6,9)|inlist(xwgempx2,1,2,3,4,5,6,9)
replace w_change=. if nyear==0
label var w_change "Rep reports one of 7 workplace changes in last 2 years"
label val w_change nyesno
ta w_change nyear, mi

* Representative reports one of 7 workplace changes occurring as a result of recession
ge w_reces=0
replace w_reces=1 if wgrecess==1
replace w_reces=0 if wgrecess==2
replace w_reces=0 if w_change==0
replace w_reces=.b if wgrecess==.b | w_change==.b
replace w_reces=.e if w_change==.b
replace w_reces=. if nyear==0
label var w_reces "Workplace change (of 7) in last 2 years as a result of the recession"
label val w_reces nyesno
ta w_reces nyear, mi

**************
* WRQ WEIGHT *
**************

* cross-sectional weight
gen w_wt=wrqwtnrc_apr13
replace w_wt=wrqwtnr_apr13 if nyear==0
replace w_wt=. if nwrq==0
label var w_wt "WRQ weight for Combined-XS"

* panel weight for workplaces with union reps
gen w_pqtuwt=tuwtnrp_apr13
replace w_pqtuwt=. if nwrq==0 
lab var w_pqtuwt "WRQ panel weight for workplaces with union rep interviews in 2004 and 2011"


**************
* Dummies *
**************

*Dummy variables for union and non-union reps
ge w_urep=w_reptyp2
replace w_urep=0 if w_reptyp2==2
replace w_urep=. if nwrq==0
label var w_urep "Union representative"
label val w_urep nyesno

ge w_nurep=0
replace w_nurep=1 if w_reptyp2==2
replace w_nurep=. if nwrq==0
label var w_nurep "Non-union representative"
label val w_nurep nyesno


*Relations between management and emp reps v/good (w_relat2)
gen w_relat2=1 if whratere==1|whratere==2
replace w_relat2=0 if whratere>2 & whratere<6
replace w_relat2=.a if whratere==.a
replace w_relat2=.b if whratere==.b
replace w_relat2=.e if whratere==.e
lab val w_relat2 yesno
lab var w_relat2 "Relations between management and emp reps v/good"

*******
* D&G *
*******

label define w_negcon 1 "Negotiates" 2 "Consults" 3 "Informs" 4 "Not inform" -7 "Incorrect Q wording" .a "Refused" .b "Don't know" .e "Item not applicable"

*Combine 04 discipline and grievance variables into one to be comparable to 11. 

ge w_disgrv=wdisgrie
replace w_disgrv=WDDISCIP if nyear==1
replace w_disgrv=1 if WDDISCIP==2 & WDGRIEV==1

* note 2011 includes disciplinary procedures as well as grievances

ge w_grvneg=WDGRIEV if nwrq2004==1
replace w_grvneg=wdisgrie if nwrq2011==1
label var w_grvneg "What reps normally do with mgt over grievance procedures"
label val w_grvneg w_negcon
ta w_grvneg nyear


*Save version of dataset containing the derived variables
* First generate a final var which we can call in var lists, knowing it is the last of the WRQ derived vars on the file
gen byte nwlast=1
label var nwlast "Last WRQ derived variable on the data file"
quietly: compress
save "$path_derived\mq&seq&wrq_derived.dta", replace

erase "$path_derived\mq&seq_derived.dta"

log close
